# dotenv-vault-python

dotenv-vault-python allows your app to sync the `.env` file to the cloud. This means that you can work anywhere, in any machine, and in any cloud infrastructure with cofidence.

- [Getting Started](#getting-started)

## Getting Started
```shell
pip install python-dotenv-vault --no-cache-dir
```

```shell
from dotenv_vault import load_dotenv

load_dotenv()
```